meetingrequest/mrgui/mrfieldbuilderplugin/inc/cesmrviewersyncfield.h
branchRCL_3
changeset 12 4ce476e64c59
parent 0 8466d47a6819
--- a/meetingrequest/mrgui/mrfieldbuilderplugin/inc/cesmrviewersyncfield.h	Mon Mar 15 12:39:10 2010 +0200
+++ b/meetingrequest/mrgui/mrfieldbuilderplugin/inc/cesmrviewersyncfield.h	Wed Mar 31 21:08:33 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2007-2009 Nokia Corporation and/or its subsidiary(-ies). 
+* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -44,25 +44,29 @@
      * C++ destructor
      */
     ~CESMRViewerSyncField();
-    
+
 public: // From CESMRField
     void InternalizeL( MESMRCalEntry& aEntry );
     void InitializeL();
     void SetOutlineFocusL( TBool aFocus );
-    
+    void LockL();
+    TBool ExecuteGenericCommandL( TInt aCommand );
+
 public: // From CCoeControl
     void SizeChanged();
     TInt CountComponentControls() const;
     CCoeControl* ComponentControl( TInt aIndex ) const;
-    
+
 private: // Implementation
     CESMRViewerSyncField();
     void ConstructL();
-    
+
 private:
     // Owned: Field icon
     CMRImage* iIcon;
-    // Owned: Field text label
+    /// Own: lock icon
+    CMRImage* iLockIcon;
+    // Not own: Field text label
     CMRLabel* iLabel;
     };